@@ -20,12 +20,5 @@ test_that("`nth_number_after_mth()` works", {
     ),
     character()
   )
-  expect_error(str_nth_number_after_mth("abc", "123", 1:2, 1:3),
-    paste(
-      "If `n` and `m` both have length greater than 1,",
-      "their lengths must be equal.\n    * Your `n` has",
-      "length 2.\n    * Your `m` has length 3."
-    ),
-    fixed = TRUE
-  )
+  expect_snapshot_error(str_nth_number_after_mth("abc", "123", 1:2, 1:3))
 })
